@@ -997,7 +997,7 @@ test_that("bindCache renderFunction basic functionality", {
 # ==============================================================================
 test_that("Custom render functions that call installExprFunction", {
   # Combinations with `installExprFunction` or `quoToFunction` plus
-  # `markRenderFunction` or `createRenderFunction` should worjk.
+  # `markRenderFunction` or `createRenderFunction` should work.
 
   # The expressions passed into renderDouble below should be converted into this
   # function. We'll use this for comparison.
@@ -1099,7 +1099,6 @@ test_that("Custom render functions that call installExprFunction", {
   # quoToFunction + markRenderFunction (with cacheHint): OK
   # Also, non-list cacheHint will get wrapped into a list
   renderDouble <- function(expr) {
-    # browser()
     func <- quoToFunction(enquo(expr), "renderDouble")
     markRenderFunction(textOutput,
       function() {
@@ -1263,3 +1262,55 @@ test_that("cacheHint to avoid collisions", {
     extractCacheHint(renderUI({ a + 1 }))
   ))
 })
+
+
+test_that("cacheHint works with quosures", {
+  # Cache hint ignores environment
+  my_quo <- local({
+    a <- 5
+    rlang::quo({a + 1})
+  })
+  ap1 <- rlang::expr({a+1})
+  plotCacheList <- list(userExpr = ap1, res = 72)
+  reactiveCacheList <- list(userExpr = ap1)
+  quoCacheList <- list(q = ap1)
+
+
+  # render**
+  # Regular expression, quoted quosure object, injected quosure object
+  expect_equal(
+    extractCacheHint(renderPlot({ a + 1 })),
+    plotCacheList
+  )
+  expect_equal(
+    extractCacheHint(renderPlot(my_quo, quoted = TRUE)),
+    plotCacheList
+  )
+  expect_equal(
+    extractCacheHint(inject(renderPlot(!!my_quo))),
+    plotCacheList
+  )
+
+  # reactive
+  # Regular expression, quoted quosure object, injected quosure object
+  expect_equal(
+    extractCacheHint(reactive(a + 1)),
+    reactiveCacheList
+  )
+  expect_equal(
+    extractCacheHint(reactive(my_quo, quoted = TRUE)),
+    reactiveCacheList
+  )
+  expect_equal(
+    extractCacheHint(inject(reactive(!!my_quo))),
+    reactiveCacheList
+  )
+
+  # markRenderFunction handles raw quosure objects as cacheHint
+  expect_equal(
+    extractCacheHint(
+      markRenderFunction(force, force, cacheHint = list(q = my_quo))
+    ),
+    quoCacheList
+  )
+})
